Module poly

Module poly 

Polynomial arithmetic in the ring Z_q[X]/(X^N + 1).

All operations are modular arithmetic modulo a prime q, in the negacyclic polynomial ring of dimension N.

Structs

Poly
A polynomial in Z_q[X]/(X^N + 1), stored as coefficient vector.